==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/panel/translations/razor-panel_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../configpaneldialog.ui" line="26"/>
        <source>Configure panel</source>
        <translation>Panel konfigurieren</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="38"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="67"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="81"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="86"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="100"/>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="130"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="135"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="140"/>
        <source>Center</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="154"/>
        <source>Alignment</source>
        <translation>Ausrichtung</translation>
    </message>
</context>
<context>
    <name>PositionAction</name>
    <message>
        <location filename="../razorpanel.cpp" line="544"/>
        <source>Top of desktop</source>
        <translation>Oben auf dem Desktop</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="545"/>
        <source>Bottom of desktop</source>
        <translation>Unten auf dem Desktop</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="546"/>
        <source>Left of desktop</source>
        <translation>Links auf dem Desktop</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="547"/>
        <source>Right of desktop</source>
        <translation>Rechts auf dem Desktop</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="554"/>
        <source>Top of desktop %1</source>
        <translation>Oben auf dem Desktop %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="555"/>
        <source>Bottom of desktop %1</source>
        <translation>Unten auf dem Desktop %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="556"/>
        <source>Left of desktop %1</source>
        <translation>Links auf dem Desktop %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="557"/>
        <source>Right of desktop %1</source>
        <translation>Rechts auf dem Desktop %1</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <location filename="../razorpanel.cpp" line="755"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="766"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="768"/>
        <source>Add plugins ...</source>
        <translation>Plugins hinzufügen ...</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="777"/>
        <source>Move plugin</source>
        <translation>Plugin verschieben</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="783"/>
        <source>Configure plugin</source>
        <translation>Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="790"/>
        <source>Delete plugin</source>
        <translation>Plugin löschen</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="797"/>
        <source>Show this panel at</source>
        <translation>Zeige dieses Panel</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="840"/>
        <source>Configure panel</source>
        <translation>Panel konfigurieren</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/panel/translations/razor-panel_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation>Panel konfigurieren</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation>Panelgröße</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation>Größe automatisch anpassen</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation>Panel Länge &amp;&amp; Position</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation>Ausrichtung:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation>Oben auf dem Desktop</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation>Links auf dem Desktop</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation>Rechts auf dem Desktop</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation>Unten auf dem Desktop</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation>Oben auf dem Desktop %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation>Links auf dem Desktop %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation>Rechts auf dem Desktop %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation>Unten auf dem Desktop %1</translation>
    </message>
</context>
<context>
    <name>RazorPanel</name>
    <message>
        <source>Panel</source>
        <translation>Anwendungsmenü</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation>Konfiguriere Panel...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation>Plugins hinzufügen ...</translation>
    </message>
</context>
<context>
    <name>RazorPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Bewegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation>Panel konfigurieren</translation>
    </message>
</context>
</TS>
